@@ -1,36 +1,22 @@
 /*
- * Copyright 2018  Friedrich W. H. Kossebau <kossebau@kde.org>
+ * SPDX-FileCopyrightText: 2018 Friedrich W. H. Kossebau <kossebau@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "util.h"
 
 // KF
-#include <KUnitConversion/Converter>
-#include <KUnitConversion/Value>
 #include <KLocalizedString>
+#include <KUnitConversion/Value>
 // Qt
 #include <QIcon>
-#include <QPixmap>
 #include <QLocale>
+#include <QPixmap>
 // Std
 #include <cmath>
 
-
-template <typename T>
-T clampValue(T value, int decimals)
+template<typename T> T clampValue(T value, int decimals)
 {
     const T mul = std::pow(static_cast<T>(10), decimals);
     return int(value * mul) / mul;
@@ -49,8 +35,7 @@ QString Util::existingWeatherIconName(const QString &iconName) const
     return isValid ? iconName : QStringLiteral("weather-not-available");
 }
 
-QString Util::temperatureToDisplayString(int displayUnitType, double value,
-                                         int valueUnitType, bool rounded, bool degreesOnly) const
+QString Util::temperatureToDisplayString(int displayUnitType, double value, int valueUnitType, bool rounded, bool degreesOnly) const
 {
     KUnitConversion::Value v(value, static_cast<KUnitConversion::UnitId>(valueUnitType));
     v = v.convertTo(static_cast<KUnitConversion::UnitId>(displayUnitType));
@@ -66,8 +51,7 @@ QString Util::temperatureToDisplayString(int displayUnitType, double value,
     return i18nc("temperature unitsymbol", "%1 %2", formattedTemp, unit);
 }
 
-QString Util::valueToDisplayString(int displayUnitType, double value,
-                                   int valueUnitType, int precision) const
+QString Util::valueToDisplayString(int displayUnitType, double value, int valueUnitType, int precision) const
 {
     KUnitConversion::Value v(value, static_cast<KUnitConversion::UnitId>(valueUnitType));
     v = v.convertTo(static_cast<KUnitConversion::UnitId>(displayUnitType));
@@ -86,7 +70,6 @@ QString Util::percentToDisplayString(double value) const
 QString Util::nameFromUnitId(KUnitConversion::UnitId unitId)
 {
     const KUnitConversion::Unit unit = m_converter.unit(unitId);
-    QString unitDescription = i18nc("@item %1 is a unit description and %2 its unit symbol",
-                                    "%1 (%2)", unit.description(), unit.symbol());
+    QString unitDescription = i18nc("@item %1 is a unit description and %2 its unit symbol", "%1 (%2)", unit.description(), unit.symbol());
     return unitDescription;
 }
